
static bool ps_WiresharkUnitTest(PS_WiresharkStream_t wsstream, u_int32 plen, void *packet)
{
	/* This function is a simplified version of my original code */
	packet_info pinfo;
	tvbuff_t *tvb = NULL;
	proto_tree *ptree = NULL;


	if(wsstream == NULL)
	{
		return false;
	}

	if(wsstream->last == NULL)
	{
		return false;
	}

	if(packet == NULL)
	{
		return false;
	}



	memset(&pinfo, 0, sizeof(packet_info));
	pinfo.current_proto = "";
	pinfo.cinfo = NULL;
	pinfo.fd = wsstream->last;

	tvb = tvb_new(TVBUFF_REAL_DATA);
	tvb_set_real_data(tvb, packet, plen, plen); /* packet and plen are respectively the
	                                             * content and the length of a datagram,
												 * captured using a SOCK_DGRAM socket
												 */

	ptree = proto_tree_create_root();
	proto_tree_set_visible(ptree, TRUE);

	TRY
	{
		call_dissector_only(
			wsstream->dissectorhandle, /* initialized to the mp2t or the rtp dissector,
			                            * using dissector_all_tables_foreach_table and
										* dissector_table_foreach_handle functions
										*/
			tvb, &pinfo, ptree);
	}
	CATCH(ReportedBoundsError)
	{
	}
	CATCH(BoundsError)
	{
	}
	CATCH(OutOfMemoryError)
	{
	}
	ENDTRY;

	proto_tree_free(ptree);
	tvb_free(tvb);



	return true;
}



bool PS_WiresharkStreamAdd(PS_WiresharkStream_t wsstream, u_int32 plen, void *packet, struct timespec *packetts)
{
	frame_data *fdata = NULL;
	
	struct timespec nullts = {0,0};

	if(wsstream == NULL)
	{
		return false;
	}

	if(packet == NULL)
	{
		return false;
	}

	if(packetts == NULL)
	{
		packetts = &nullts;
	}
	
	fdata = g_malloc(sizeof(frame_data));
	fdata->prev = NULL;
	fdata->next = NULL;
	fdata->pfd = NULL;
	fdata->num = 1;
	fdata->pkt_len = plen;
	fdata->cum_bytes = plen;
	fdata->cap_len = plen;
	fdata->file_off = 0;
	fdata->lnk_t = WTAP_ENCAP_ETHERNET;
	fdata->abs_ts.secs = packetts->tv_sec;
	fdata->abs_ts.nsecs = packetts->tv_nsec;
	fdata->flags.passed_dfilter = 0;
	fdata->flags.encoding = CHAR_ASCII;
	fdata->flags.visited = 0;
	fdata->flags.marked = 0;
	fdata->flags.ref_time = 0;
	fdata->color_filter = NULL;

	
	wsstream->last = fdata;

	
	return ps_WiresharkUnitTest(wsstream, plen, packet);
}


bool PS_WiresharkStreamFree(PS_WiresharkStream_t wsstream)
{
	frame_data *curframe = NULL;

	if(wsstream == NULL)
	{
		return false;
	}

	g_free(wsstream->last);

	free(wsstream);
	return true;
}


